gcp_zone
:   The name of the availability zone where the compute instance and disks
    to be backed up in a snapshot backup are located. Required when
    the `snapshot` value is specified for `backup_method` and
    `snapshot_provider` is set to `gcp`.

    Scope: Server/Model.
